@@ -54,15 +54,16 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
                     res_tb.add_row([aim.split(dir_char)[-1], 'No File', ''])
                     img_set[aim] = False
                 else:
+                    res_plt = list(res_dict['data']['url'].keys())[0]
                     res_tb.add_row([aim.split(dir_char)[-1], res_dict['msg'],
                                     '' if res['code'] != 200 else (
-                                        res_dict['data']['url'][plt_type]
-                                        if res_dict['data']['url'][plt_type].lower() != 'null'
-                                        else plt_type + ' failed')]
+                                        res_dict['data']['url'][res_plt]
+                                        if res_dict['data']['url'][res_plt].lower() != 'null'
+                                        else res_plt + ' failed')]
                                    )
                     if res_dict['code'] != 200:
                         break
-                    img_set[aim] = res_dict['data']['url'][plt_type] if res_dict['code'] != 200 else False
+                    img_set[aim] = res_dict['data']['url'][res_plt] if res_dict['code'] != 200 else False
             if img_set[aim]:
                 ct = ct.replace(raw_path, img_set[aim])
         with open(path, 'w') as fp:
@@ -82,6 +83,7 @@ def upload_image(filePath: str, plt_type: str = 'Ali'):
             if not res:
                 tb.add_row([filePath.split(dir_char)[-1], 'No File', ''])
             else:
+                plt_type = list(res['data']['url'].keys())[0]
                 tb.add_row([filePath.split(dir_char)[-1], res['msg'],
                             '' if res['code'] != 200 else (
                                 res['data']['url'][plt_type]
@@ -159,7 +161,14 @@ def ip_info(ip: str):
                         headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                         if ip and alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'}
                         if ip else headers.update({'token': alapi_token} if alapi_token else headers))
-    return json.loads(res.text)['data']
+    try:
+        res = json.loads(res.text)
+        if res['code'] != 200:
+            return [ip, '', res['msg'], '{code, %s}' % res['code']]
+        return res['data']
+    except :
+        print(res.text)
+        return [ip, '', '网络错误', '{code, %s}' % res.status_code]
 
 
 def garbage_classification(query_ls: list):
@@ -205,3 +214,25 @@ def garbage_classification(query_ls: list):
         else:
             table.add_row([fmt_string(query_el, 0), 'Unknown', 'None', 'Request Error'])
     return str(table)
+
+
+def short_video_info(url: str):
+    """
+    解析多平台短视频，并返回视频信息与下载直链
+
+    Parse multi - platform short video and return video information with download straight link
+
+    :param url: 短视频分享链接 | Short video sharing link
+    :return:
+    """
+    res = requests.post("https://v1.alapi.cn/api/video/url", data="url={}".format(quote(url, 'utf-8')),
+                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                        if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
+    try:
+        res = json.loads(res.text)
+        if res['code'] != 200:
+            return False, {'title': res['msg'], 'cover_url': 'None', 'video_url': 'None', 'source': res['code']}
+        return True, res['data']
+    except :
+        return False, {'title': '网络错误' if user_lang == 'zh' else 'Network Error',
+                       'cover_url': 'None', 'video_url': 'None', 'source': 'Unknown'}
